import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_payment/ocg_payment.dart';
import 'package:ocg_payment/src/modals/method.dart';

abstract class PaymentMethodListEvent {}

class PaymentMethodListRefreshEvent extends PaymentMethodListEvent {}

class PaymentMethodAddEvent extends PaymentMethodListEvent {
  final PaymentMethod method;

  PaymentMethodAddEvent(this.method);
}

abstract class PaymentMethodListState {}

class PaymentMethodListInitialState extends PaymentMethodListState {}

class PaymentMethodListLoadingState extends PaymentMethodListState {}

class PaymentMethodListLoadedState extends PaymentMethodListState {
  final List<PaymentMethod> paymentMethods;
  PaymentMethodListLoadedState(this.paymentMethods);
}

class PaymentMethodListErrorState extends PaymentMethodListState {
  final String error;
  PaymentMethodListErrorState(this.error);
}

class PaymentMethodListBloc
    extends Bloc<PaymentMethodListEvent, PaymentMethodListState> {
  final PaymentRepository paymentRepository;
  PaymentMethodListBloc(this.paymentRepository)
      : super(PaymentMethodListInitialState());
  @override
  Stream<PaymentMethodListState> mapEventToState(
      PaymentMethodListEvent event) async* {
    if (event is PaymentMethodListRefreshEvent) {
      yield PaymentMethodListLoadingState();
      AppResponse<List<PaymentMethod>> response =
          await paymentRepository.getMethods();
      if (response.isSuccess) {
        yield PaymentMethodListLoadedState(response.data);
      } else {
        yield PaymentMethodListErrorState(response.error);
      }
    }
    if (event is PaymentMethodAddEvent) {
      var response = await paymentRepository.addMethod(event.method);
      if (response.isSuccess) {
        add(PaymentMethodListRefreshEvent());
      }
    }
  }
}
