import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:ocg_payment/ocg_payment.dart';

abstract class PaymentMultipleBalanceEvent {}

class PaymentMultipleBalanceCheckEvent extends PaymentMultipleBalanceEvent {}

class PaymentMultipleBalanceAddEvent extends PaymentMultipleBalanceEvent {
  final Amount amount;

  PaymentMultipleBalanceAddEvent(this.amount);
}

abstract class PaymentMultipleBalanceState {}

class PaymentMultipleBalanceSuccessState extends PaymentMultipleBalanceState {
  final List<PaymentBalance> balances;

  PaymentMultipleBalanceSuccessState(this.balances);
}

class PaymentMultipleBalanceLoadingState extends PaymentMultipleBalanceState {}

class PaymentMultipleBalanceErrorState extends PaymentMultipleBalanceState {
  final String error;

  PaymentMultipleBalanceErrorState(this.error);
}

class PaymentMultipleBalanceInitialState extends PaymentMultipleBalanceState {}

class PaymentMultipleBalanceBloc
    extends Bloc<PaymentMultipleBalanceEvent, PaymentMultipleBalanceState> {
  final PaymentRepository paymentRepository;
  PaymentMultipleBalanceBloc(this.paymentRepository)
      : super(PaymentMultipleBalanceInitialState());

  @override
  Stream<PaymentMultipleBalanceState> mapEventToState(
      PaymentMultipleBalanceEvent event) async* {
    if (event is PaymentMultipleBalanceCheckEvent) {
      yield PaymentMultipleBalanceLoadingState();
      var response = await paymentRepository.getMultipleBalances();
      if (response.isSuccess) {
        var list = response.data;
        String currency = await paymentRepository.getCurrency();
        int index =
            list.indexWhere((element) => element.amount?.currency == currency);
        if (index >= 0) {
          var balance = list[index];
          list.removeAt(index);
          list.insert(0, balance);
        }
        yield PaymentMultipleBalanceSuccessState(list);
      } else {
        yield PaymentMultipleBalanceErrorState(response.error);
      }
    }
    if (event is PaymentMultipleBalanceAddEvent) {
      yield PaymentMultipleBalanceLoadingState();
      var response = await paymentRepository.addAmount(event.amount);
      if (response.isSuccess) {
        add(PaymentMultipleBalanceCheckEvent());
      } else {
        yield PaymentMultipleBalanceErrorState(response.error);
        add(PaymentMultipleBalanceCheckEvent());
      }
    }
  }
}
