import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_payment/src/modals/transaction.dart';
import 'package:ocg_payment/src/repository/base.dart';

abstract class PaymentTransactionListEvent {}

class PaymentTransactionListRefreshEvent extends PaymentTransactionListEvent {}

abstract class PaymentTransactionListState {}

class PaymentTransactionListInitialState extends PaymentTransactionListState {}

class PaymentTransactionListLoadingState extends PaymentTransactionListState {}

class PaymentTransactionListLoadedState extends PaymentTransactionListState {
  final List<PaymentTransaction> transactions;
  PaymentTransactionListLoadedState(this.transactions);
}

class PaymentTransactionListErrorState extends PaymentTransactionListState {
  final String error;
  PaymentTransactionListErrorState(this.error);
}

class PaymentTransactionListBloc
    extends Bloc<PaymentTransactionListEvent, PaymentTransactionListState> {
  final PaymentRepository repository;
  PaymentTransactionListBloc(this.repository)
      : super(PaymentTransactionListInitialState());
  @override
  Stream<PaymentTransactionListState> mapEventToState(
      PaymentTransactionListEvent event) async* {
    if (event is PaymentTransactionListRefreshEvent) {
      yield PaymentTransactionListLoadingState();
      AppResponse<List<PaymentTransaction>> response =
          await repository.getTransactions();
      if (response.isSuccess) {
        yield PaymentTransactionListLoadedState(response.data);
      } else {
        yield PaymentTransactionListErrorState(response.error);
      }
    }
  }
}
