import 'package:json_annotation/json_annotation.dart';
import 'package:intl/intl.dart';
part 'amount.g.dart';

NumberFormat formatter = NumberFormat("##,##,##,000");

@JsonSerializable(explicitToJson: true)
class Amount {
  final double amount;
  final String currency;

  Amount(this.amount, this.currency);
  Amount.named({this.amount, this.currency});

  Amount copyWith({double amount, String currency}) {
    return Amount.named(
        amount: amount ?? this.amount, currency: currency ?? this.currency);
  }

  operator +(Amount other) {
    assert(other.currency.toLowerCase() == currency.toLowerCase());
    return Amount.named(
        amount: (amount ?? 0) + other.amount, currency: currency);
  }

  Amount operator *(double scale) {
    return this.copyWith(amount: (amount * scale).toDouble());
  }

  Map<String, dynamic> toJson() => _$AmountToJson(this);

  factory Amount.fromJson(json) => _$AmountFromJson(json);

  String toString() =>
      "${NumberFormat().simpleCurrencySymbol(currency)} ${formatter.format(amount)}";
}
