import 'package:flutter/material.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_payment/ocg_payment.dart';
import 'package:ocg_payment/src/modals/amount.dart';
import 'package:ocg_payment/src/modals/balance.dart';

class PaymentTestRepository extends PaymentRepository {
  PaymentBalance _balance;

  List<PaymentMethod> _methods;

  PaymentTestRepository() {
    _methods = [
      // Banks
      PaymentBank.named(
        id: "1",
        branch: "Mumbai, IN",
        ifsc: "SBIN0000058",
        account: "487628715172",
        holderName: 'Bhavneet Singh Bhalla',
      ),
      // Cards
      PaymentCard.named(
          id: "1",
          amount: 100,
          currency: "USD",
          cardNo: "4616900007729988",
          color: Colors.white,
          cvv: "123",
          expiryDate: DateTime(
            2022,
          ),
          logo:
              "https://logos-world.net/wp-content/uploads/2020/04/Visa-Logo.png"),
      // Wallets
      PaymentWallet.named(
          id: "1",
          amount: 100,
          currency: "USD",
          name: 'Paypal',
          logo:
              "https://cdn4.iconfinder.com/data/icons/logos-and-brands/512/250_Paypal_logo-512.png"),
    ];

    _balance = PaymentBalance.named(
        amount: Amount.named(amount: 0, currency: "USD"),
        id: IDHelper().generateId(),
        userId: "sample");
  }

  @override
  Future<AppResponse<PaymentResponse>> payAmount(PaymentRequest request) async {
    try {
      if (request.amount > _balance.amount.amount) {
        return AppResponse.named(error: "Not enough balance");
      }
      _balance = _balance.addBalance(
          Amount.named(amount: -request.amount, currency: request.currency));
      await Future.delayed(Duration(milliseconds: 400));
      return AppResponse.named(
          data: PaymentResponse.named(id: IDHelper().generateId()));
    } catch (e) {
      return AppResponse.named(error: "$e");
    }
  }

  @override
  Future<AppResponse<List<PaymentMethod>>> getMethods() async {
    await Future.delayed(Duration(milliseconds: 10));
    return AppResponse.named(data: _methods);
  }

  @override
  Future<AppResponse<String>> addMethod(PaymentMethod method) async {
    assert(method.type != null);
    await Future.delayed(Duration(milliseconds: 10));
    String id = IDHelper().generateId();
    if (method is PaymentBank) {
      method = (method as PaymentBank).copyWith(id: id);
    }
    if (method is PaymentCard) {
      method = (method as PaymentCard).copyWith(id: id);
    }
    _methods.add(method);
    return AppResponse.named(data: id);
  }

  @override
  Future<AppResponse<PaymentBalance>> getBalance() async {
    return AppResponse.named(data: _balance);
  }

  @override
  Future<AppResponse<bool>> addAmount(Amount amount) async {
    try {
      debugPrint("Amount ${amount.amount}");
      _balance = _balance.addBalance(amount);
      debugPrint("Balance ${_balance.amount.amount}");
      return AppResponse.named(data: true);
    } catch (e) {
      return AppResponse.named(error: e.toString());
    }
  }

  @override
  Future<AppResponse<List<PaymentTransaction>>> getTransactions() {
    // TODO: implement getTransactions
    throw UnimplementedError();
  }

  @override
  Future<String> getCurrency() {
    // TODO: implement getCurrency
    throw UnimplementedError();
  }
}
