import 'package:flutter/material.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_payment/ocg_payment.dart';

class PaymentBankWidget extends StatelessWidget {
  final PaymentBank bank;
  final bool isSelected;
  final Function(PaymentBank bank, bool isSelected) onSelected;

  const PaymentBankWidget(
      {Key key, this.bank, this.isSelected = false, this.onSelected})
      : super(key: key);
  @override
  Widget build(BuildContext context) {
    return LayoutBuilder(builder: (context, constraints) {
      double width = constraints.biggest.width;
      return Container(
        child: EaseInWidget(
          child: Container(
            decoration: BoxDecoration(
                border: Border.all(
                  style: BorderStyle.solid,
                  color: Colors.black12,
                ),
                color: isSelected ? Colors.white : Color(0xFFF9F8FD),
                borderRadius: BorderRadius.all(Radius.circular(8)),
                boxShadow: [
                  BoxShadow(
                    color: Color(0xFFE4E4E4).withOpacity(0.3),
                    blurRadius: 12.0,
                    spreadRadius: 0.1,
                    offset: Offset(
                      4.0,
                      4.0,
                    ),
                  )
                ]),
            padding:
                EdgeInsets.symmetric(horizontal: width * 0.05, vertical: 15),
            child: Row(
              children: [
                Icon(
                  Icons.monetization_on,
                  color: Colors.black54,
                  size: 32,
                ),
                SizedBox(
                  width: 18,
                ),
                Expanded(
                  child: Column(
                    mainAxisAlignment: MainAxisAlignment.start,
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      Text(
                        "${bank.account}",
                        style: TextStyle(
                            fontSize: 16,
                            color: Color(0xFF0D0B22),
                            fontWeight: FontWeight.w600),
                      ),
                      SizedBox(
                        height: 4,
                      ),
                      Text(
                        "${bank.holderName}",
                        style:
                            TextStyle(fontSize: 14, color: Color(0xFF565656)),
                      )
                    ],
                  ),
                ),
                SizedBox(
                  width: 18,
                ),
                isSelected
                    ? Icon(
                        Icons.check_circle,
                        color: Colors.green,
                        size: 28,
                      )
                    : Container(
                        width: 0,
                        height: 0,
                      )
              ],
            ),
          ),
          onTap:
              onSelected == null ? null : () => onSelected(bank, !isSelected),
        ),
      );
    });
  }
}
