import 'package:flutter/material.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_payment/ocg_payment.dart';
import 'package:ocg_payment/src/metadata/form_style.dart';
import 'package:ocg_payment/src/widgets/text_field.dart';

class CardForm extends StatefulWidget {
  final Function(PaymentCard card) onSubmit;
  final Widget actionBtn;
  CardForm({Key key, this.onSubmit, this.actionBtn}) : super(key: key);

  @override
  _CardFormState createState() => _CardFormState();
}

class _CardFormState extends State<CardForm> {
  PaymentCard _card;
  final GlobalKey<FormState> _formKey = GlobalKey<FormState>();
  TextEditingController _controller;

  @override
  void initState() {
    super.initState();
    _card = PaymentCard.named();
    _controller = TextEditingController();
  }

  @override
  Widget build(BuildContext context) {
    return Form(
      key: _formKey,
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.stretch,
        children: [
          TextFieldLabelWidget(
            labelText: "Card No",
            textInputType: TextInputType.number,
            labelStyle: FormStyle.addBankAccountLabelStyle,
            focusedBorder: FormStyle.addBankFocusedBorder,
            enabledBorder: FormStyle.addBankEnabledBorder,
            onChanged: (val) {
              _card = _card.copyWith(cardNo: val);
            },
            maxLength: 16,
            validator: (val) => InputHelper.isBlank(val)
                ? "Please enter card number"
                : val.length != 16
                    ? "Please enter valid number"
                    : null,
          ),
          Row(
            children: [
              Expanded(
                child: TextFieldLabelWidget(
                  labelText: "CVV",
                  textInputType: TextInputType.number,
                  labelStyle: FormStyle.addBankAccountLabelStyle,
                  focusedBorder: FormStyle.addBankFocusedBorder,
                  enabledBorder: FormStyle.addBankEnabledBorder,
                  maxLength: 3,
                  onChanged: (val) {
                    _card = _card.copyWith(cvv: val);
                  },
                  validator: (val) =>
                      InputHelper.isBlank(val) ? "Please enter " + "cvv" : null,
                ),
              ),
              SizedBox(
                width: 24,
              ),
              Expanded(
                child: TextFieldLabelWidget(
                  labelText: "Date of expiry",
                  textInputType: TextInputType.text,
                  labelStyle: FormStyle.addBankAccountLabelStyle,
                  focusedBorder: FormStyle.addBankFocusedBorder,
                  enabledBorder: FormStyle.addBankEnabledBorder,
                  maxLength: 15,
                  onTap: () async {
                    var date = await showDatePicker(
                        context: context,
                        initialDate: DateTime.now(),
                        firstDate: DateTime(DateTime.now().year - 1),
                        lastDate: DateTime(DateTime.now().year + 1));
                    if (date != null) {
                      _card = _card.copyWith(expiryDate: date);
                      _controller.text = DateHelper.beautifyDate(
                          _card.expiryDate,
                          relative: false);
                    }
                  },
                  readOnly: true,
                  controller: _controller,
                  validator: (val) => InputHelper.isBlank(val)
                      ? "Please enter " + "expiry date"
                      : null,
                ),
              )
            ],
          ),
          SizedBox(
            height: 18,
          ),
          widget.actionBtn != null
              ? GestureDetector(
                  onTap: _onSubmit,
                  child: widget.actionBtn,
                )
              : RoundedButton("Continue", onTap: _onSubmit)
        ],
      ),
    );
  }

  void _onSubmit() {
    if (_formKey.currentState.validate()) {
      widget.onSubmit(_card);
    }
  }
}
