import 'package:flutter/material.dart';
import 'package:ocg_payment/src/metadata/colors.dart';
import 'package:ocg_payment/src/metadata/form_style.dart';

class TextFieldLabelWidget extends StatelessWidget {
  final TextEditingController controller;
  final String labelText;
  final String helperText;
  final String initialValue;
  final String suffixText;
  final int maxLength;
  final int maxLines;
  final TextStyle suffixStyle;
  final TextStyle labelStyle;
  final TextStyle inputStyle;
  final TextStyle helperStyle;
  final TextInputType textInputType;
  final bool expands;
  final bool enabled;
  final bool isDense;
  final Function(String) validator;
  final Function(String) onSaved;
  final ValueChanged<String> onChanged;
  final GestureTapCallback onTap;
  final InputBorder border;
  final InputBorder focusedBorder;
  final InputBorder enabledBorder;
  final InputBorder disabledBorder;
  final EdgeInsets contentPadding;
  final Widget prefixIcon;
  final bool readOnly;

  TextFieldLabelWidget(
      {@required this.labelText,
      this.prefixIcon,
      this.textInputType = TextInputType.text,
      this.maxLength,
      this.maxLines,
      this.expands = false,
      this.inputStyle = FormStyle.defaultTextFieldInputStyle,
      this.helperText,
      this.helperStyle = FormStyle.helperStyleDefault,
      this.labelStyle = FormStyle.labelStyleDefault,
      this.controller,
      this.validator,
      this.onSaved,
      this.readOnly = false,
      this.focusedBorder = FormStyle.border,
      this.enabledBorder = FormStyle.border,
      this.initialValue,
      this.suffixText,
      this.suffixStyle,
      this.onTap,
      this.onChanged,
      this.disabledBorder,
      this.enabled,
      this.border = FormStyle.border,
      this.contentPadding,
      this.isDense});

  @override
  Widget build(BuildContext context) {
    return TextFormField(
      initialValue: initialValue,
      controller: controller,
      decoration: InputDecoration(
          prefixIcon: prefixIcon,
          labelText: labelText,
          labelStyle: labelStyle,
          border: border,
          focusedBorder: focusedBorder,
          enabledBorder: enabledBorder,
          disabledBorder: disabledBorder,
          filled: false,
          fillColor: Colors.grey[200],
          helperText: helperText,
          helperStyle: helperStyle,
          suffixText: suffixText,
          suffixStyle: suffixStyle,
          isDense: isDense,
          contentPadding: contentPadding),
      cursorColor: MetaColors.darkGrey,
      style: inputStyle,
      keyboardType: textInputType,
      expands: expands,
      validator: validator,
      onSaved: onSaved,
      onTap: onTap,
      enabled: enabled,
      onChanged: onChanged,
      maxLength: maxLength,
      maxLines: maxLines,
      readOnly: readOnly,
    );
  }
}
